## Version 0.0.81

This new version introduces a significant enhancement to the QueryBot class, providing more control over the printing of debug messages.

### New Features

- Added a 'verbose' parameter to the QueryBot class to control the printing of debug messages (eee3e9) (Eric Ma)
- Updated the initialization of the LangChain model to use the new 'verbose' parameter instead of a hardcoded value (eee3e9) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
